@@ -136,7 +136,7 @@ class _Simulate(_BaseRateSimulator[Model]):
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         """Plot simulation results for a selection of compounds."""
         compounds = self.model.get_compounds()
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = self.get_full_results_df(normalise=normalise, concatenated=True)
         if y is None:
             return None, None
         return plot(
@@ -159,7 +159,8 @@ class _Simulate(_BaseRateSimulator[Model]):
         )
 
     def store_results_to_file(self, filename: str, filetype: Optional[str] = None) -> None:
-        if self.time is None or self.results is None:
+        time = self.get_time(concatenated=False)
+        if time is None or self.results is None:
             raise ValueError("Cannot save results, since none are stored in the simulator")
 
         path = Path(filename)
@@ -167,12 +168,11 @@ class _Simulate(_BaseRateSimulator[Model]):
         path = _add_suffix(path, file_type)
 
         results = [i.tolist() for i in self.results]
-        time = [i.tolist() for i in cast(List[Array], self.get_time(concatenated=False))]
         parameters = cast(List[Dict[str, float]], self.simulation_parameters)
 
         to_export = {
             "results": results,
-            "time": time,
+            "time": [i.tolist() for i in time],
             "parameters": parameters,
         }
 
